@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-03-28'; # DATE
 our $DIST = 'Parse-FireDiamond'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(
@@ -71,23 +71,23 @@ our %fire_hazard_attrs = (
 our %reactivity_attrs = (
     4 => {
         meaning => "may detonate",
-        explanation => "",
+        explanation => "Readily capable of detonation or explosive decomposition at normal temperatures and pressures (e.g. nitroglycerin, chlorine dioxide, nitrogen triiodide, manganese heptoxide, TNT)",
     },
     3 => {
         meaning => "shock + heat may detonate",
-        explanation => "",
+        explanation => "Capable of detonation or explosive decomposition but requires a strong initiating source, must be heated under confinement before initiation, reacts explosively with water, or will detonate if severely shocked (e.g. ammonium nitrate, caesium, hydrogen peroxide)",
     },
     2 => {
         meaning => "violent reaction",
-        explanation => "",
+        explanation => "Undergoes violent chemical change at elevated temperatures and pressures, reacts violently with water, or may form explosive mixtures with water (e.g. white phosphorus, potassium, sodium)",
     },
     1 => {
         meaning => "unstable if heated",
-        explanation => "",
+        explanation => "Normally stable, but can become unstable at elevated temperatures and pressures (e.g. propene, ammonium acetate, carbonic acid)",
     },
     0 => {
         meaning => "stable",
-        explanation => "",
+        explanation => "Normally stable, even under fire exposure conditions, and is not reactive with water (e.g. helium, N2, carbon dioxide)",
     },
 );
 
@@ -160,7 +160,7 @@ our %specific_hazard_attrs = (
     },
 );
 
-$SPEC{parse_fire_diamond_text} = {
+$SPEC{parse_fire_diamond_text_notation} = {
     v => 1.1,
     summary => 'Parse Fire Diamond (NFPA 704) text notation',
     args => {
@@ -185,7 +185,7 @@ $SPEC{parse_fire_diamond_text} = {
         },
     ],
 };
-sub parse_fire_diamond_text {
+sub parse_fire_diamond_text_notation {
     my %args = @_;
 
     my $notation = $args{notation} or return [400, "Please specify notation"];
@@ -248,7 +248,7 @@ Parse::FireDiamond - Parse Fire Diamond (NFPA 704) notation
 
 =head1 VERSION
 
-This document describes version 0.002 of Parse::FireDiamond (from Perl distribution Parse-FireDiamond), released on 2023-03-28.
+This document describes version 0.003 of Parse::FireDiamond (from Perl distribution Parse-FireDiamond), released on 2023-03-28.
 
 =head1 SYNOPSIS
 
@@ -265,11 +265,11 @@ Keywords: chemicals, materials, hazardous, safety.
 =head1 FUNCTIONS
 
 
-=head2 parse_fire_diamond_text
+=head2 parse_fire_diamond_text_notation
 
 Usage:
 
- parse_fire_diamond_text(%args) -> [$status_code, $reason, $payload, \%result_meta]
+ parse_fire_diamond_text_notation(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Parse Fire Diamond (NFPA 704) text notation.
 
@@ -279,7 +279,7 @@ Examples:
 
 =item * Parse the fire diamond for citric acid:
 
- parse_fire_diamond_text(notation => "H2/F1/R0/");
+ parse_fire_diamond_text_notation(notation => "H2/F1/R0/");
 
 Result:
 
@@ -297,13 +297,13 @@ Result:
    {
      "func.fire_hazard_explanation"   => "",
      "func.health_hazard_explanation" => "Intense or continued but not chronic exposure could cause temporary incapacitation or possible residual injury (e.g. diethyl ether, ammonium phosphate, carbon dioxide, chloroform, DEET).",
-     "func.reactivity_explanation"    => "",
+     "func.reactivity_explanation"    => "Normally stable, even under fire exposure conditions, and is not reactive with water (e.g. helium, N2, carbon dioxide)",
    },
  ]
 
 =item * Parse the fire diamond for sucrose:
 
- parse_fire_diamond_text(notation => "H0/F1/R0/");
+ parse_fire_diamond_text_notation(notation => "H0/F1/R0/");
 
 Result:
 
@@ -321,13 +321,13 @@ Result:
    {
      "func.fire_hazard_explanation"   => "",
      "func.health_hazard_explanation" => "Poses no health hazard, no precautions necessary and would offer no hazard beyond that of ordinary combustible materials (e.g. wood, sugar, salt, propylene glycol)",
-     "func.reactivity_explanation"    => "",
+     "func.reactivity_explanation"    => "Normally stable, even under fire exposure conditions, and is not reactive with water (e.g. helium, N2, carbon dioxide)",
    },
  ]
 
 =item * Parse the fire diamond for sulfuric acid:
 
- parse_fire_diamond_text(notation => "H3/F0/R2/W+OX");
+ parse_fire_diamond_text_notation(notation => "H3/F0/R2/W+OX");
 
 Result:
 
@@ -349,7 +349,7 @@ Result:
    {
      "func.fire_hazard_explanation"   => "Materials that will not burn under typical fire conditions (e.g. carbon tetrachloride, silicon dioxide, perfluorohexane), including intrinsically noncombustible materials such as concrete, stone, and sand. Materials that will not burn in air unless exposed to a temperature of 820 \xC2\xB0C (1,500 \xC2\xB0F) for more than 5 minutes.",
      "func.health_hazard_explanation" => "Short exposure could cause serious temporary or moderate residual injury (e.g. liquid hydrogen, sulfuric acid, calcium hypochlorite, carbon monoxide, hexafluorosilicic acid, zinc chloride, sodium hydroxide)",
-     "func.reactivity_explanation"    => "",
+     "func.reactivity_explanation"    => "Undergoes violent chemical change at elevated temperatures and pressures, reacts violently with water, or may form explosive mixtures with water (e.g. white phosphorus, potassium, sodium)",
      "func.specific_hazards"          => [
                                            {
                                              explanation => "Reacts with water in an unusual or dangerous manner (e.g. caesium, sodium, diborane, sulfuric acid)",
